@startuml mikuna database
skinparam Monochrome reverse
skinparam class {
    FontName "Victor Mono"
}
skinparam arrow {
    FontName "Victor Mono"
}
skinparam classAttribute {
    FontName "Victor Mono"
}


enum Dimension {
    MASS 
    VOLUME
    NONE
}

enum Sex {
    FEMALE
    MALE
}

class Ingredient {
    id: UUID
    ---
    name_fr: String
    name_en: String
    name_scientific: String
    image_url: URL
    ---
    carbohydrates: Float
    proteins: Float
    lipids: Float
    energy: Float
    ---
    dimension: Dimension
}

class QuantifiedIngredient {
    id: UUID
    ---
    quantity: Float
}

class Meal {
    id: UUID
    ---
    name_fr: String
    name_en: String
    image_url: URL
    ===
    carbohydrates: Float
    proteins: Float
    lipids: Float
    energy: Float
}

class Activity {
    id: UUID
    ---
    name_fr: String
    name_en: String
    ---
    carbohydrates_per_hour: Float
    proteins_per_hour: Float
    lipids_per_hour: Float
    energy_per_hour: Float
}

class Account {
    id: UUID
    ---
    name: String
    email: Email
    password_hash: ArgonHash
    ---
    sex: Sex
    age: Int
    weight: Float
    vegan: Boolean
    halal_only: Boolean
}

class ActivityWithDuration {
    id: UUID
    ---
    duration: Float
}

class MealPlan {
    id: UUID
    ---
    name: String
    ===
    complete: Boolean
}

Meal "1" --> "0..n" QuantifiedIngredient : "The ingredients in a meal"
Ingredient "1" --> "*" QuantifiedIngredient

Account "1" --> "0..n" Meal : "Custom meals"

Account "1" --> "0..n" MealPlan : "Different schedules (e.g. weekend vs weekday)"
MealPlan "1" --> "0..n" ActivityWithDuration : "The activities in a day (a schedule)"
Activity "1" --> "*" ActivityWithDuration

MealPlan "1" --> "0..3" Meal : "A day plan"
